@@ -77,7 +77,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
     /**
      * Returns TRUE if the widget's clear button is visible.
      * \see setShowClearButton()
-     * \since QGIS 3.0
      */
     bool showClearButton() const { return mClearButtonVisible; }
 
@@ -85,7 +84,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Sets whether the widget's clear button is visible.
      * \param visible set to FALSE to hide the clear button
      * \see showClearButton()
-     * \since QGIS 3.0
      */
     void setShowClearButton( bool visible );
 
@@ -93,7 +91,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Returns the clear mode for the widget. The clear mode defines the behavior of the
      * widget when its value is cleared. This defaults to ClearToNull.
      * \see setClearMode()
-     * \since QGIS 3.0
      */
     ClearMode clearMode() const { return mClearMode; }
 
@@ -101,7 +98,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Sets the clear mode for the widget. The clear mode defines the behavior of the
      * widget when its value is cleared. This defaults to ClearToNull.
      * \see clearMode()
-     * \since QGIS 3.0
      */
     void setClearMode( ClearMode mode ) { mClearMode = mode; }
 
@@ -125,14 +121,12 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Define if a search icon shall be shown on the left of the image
      * when no text is entered
      * \param visible set to FALSE to hide the search icon
-     * \since QGIS 3.0
      */
     void setShowSearchIcon( bool visible );
 
     /**
      * Returns if a search icon shall be shown on the left of the image
      * when no text is entered
-     * \since QGIS 3.0
      */
     bool showSearchIcon() const { return static_cast< bool >( mSearchAction ); }
 
@@ -143,9 +137,8 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * \param defaultValue default value
      * \see defaultValue()
      * \see clearMode()
-     * \since QGIS 3.0
      */
-    void setDefaultValue( const QString &defaultValue ) { mDefaultValue = defaultValue; }
+    void setDefaultValue( const QString &defaultValue );
 
     /**
      * Returns the default value for the widget. The default value is a value
@@ -153,7 +146,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * is equal to ClearToDefault.
      * \see setDefaultValue()
      * \see clearMode()
-     * \since QGIS 3.0
      */
     QString defaultValue() const { return mDefaultValue; }
 
@@ -188,7 +180,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Show a spinner icon. This can be used for search boxes to indicate that
      * something is going on in the background.
      *
-     * \since QGIS 3.0
      */
     bool showSpinner() const;
 
@@ -196,21 +187,18 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Show a spinner icon. This can be used for search boxes to indicate that
      * something is going on in the background.
      *
-     * \since QGIS 3.0
      */
     void setShowSpinner( bool showSpinner );
 
     /**
      * Will select all text when this widget receives the focus.
      *
-     * \since QGIS 3.0
      */
     bool selectOnFocus() const;
 
     /**
      * Will select all text when this widget receives the focus.
      *
-     * \since QGIS 3.0
      */
     void setSelectOnFocus( bool selectOnFocus );
 
@@ -218,7 +206,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Reimplemented to enable/disable the clear action
      * depending on read-only status
      *
-     * \since QGIS 3.0.1
      */
     bool event( QEvent *event ) override;
 
@@ -233,7 +220,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
     /**
      * Clears the widget and resets it to the null value.
      * \see nullValue()
-     * \since QGIS 3.0
      */
     virtual void clearValue();
 
@@ -268,7 +254,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
      * Show a spinner icon. This can be used for search boxes to indicate that
      * something is going on in the background.
      *
-     * \since QGIS 3.0
      */
     void showSpinnerChanged();
 
@@ -276,7 +261,6 @@ class GUI_EXPORT QgsFilterLineEdit : public QLineEdit
     /**
      * Will select all text when this widget receives the focus.
      *
-     * \since QGIS 3.0
      */
     void selectOnFocusChanged();
 
