@@ -21,8 +21,8 @@
 #include "qgis_core.h"
 #include "qgsdataprovider.h"
 #include "qgspointcloudattribute.h"
-#include "qgsstatisticalsummary.h"
 #include "qgspointcloudindex.h"
+#include "qgspointcloudsubindex.h"
 #include "qgspoint.h"
 #include "qgsray3d.h"
 #include <memory>
@@ -31,6 +31,7 @@ class IndexedPointCloudNode;
 class QgsPointCloudIndex;
 class QgsPointCloudRenderer;
 class QgsGeometry;
+class QgsPointCloudStatistics;
 
 /**
  * \ingroup core
@@ -50,12 +51,13 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
     /**
      * Capabilities that providers may implement.
      */
-    enum Capability
+    enum Capability SIP_ENUM_BASETYPE( IntFlag )
     {
       NoCapabilities = 0,       //!< Provider has no capabilities
       ReadLayerMetadata = 1 << 0, //!< Provider can read layer metadata from data store.
       WriteLayerMetadata = 1 << 1, //!< Provider can write layer metadata to the data store. See QgsDataProvider::writeLayerMetadata()
       CreateRenderer = 1 << 2, //!< Provider can create 2D renderers using backend-specific formatting information. See QgsPointCloudDataProvider::createRenderer().
+      ContainSubIndexes = 1 << 3, //!< Provider can contain multiple indexes. Virtual point cloud files for example (since QGIS 3.32)
     };
 
     Q_DECLARE_FLAGS( Capabilities, Capability )
@@ -63,7 +65,7 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
     /**
      * Point cloud index state
      */
-    enum PointCloudIndexGenerationState
+    enum PointCloudIndexGenerationState SIP_ENUM_BASETYPE( IntFlag )
     {
       NotIndexed = 0, //!< Provider has no index available
       Indexing = 1 << 0, //!< Provider try to index the source data
@@ -85,8 +87,6 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      * and a range \a extentZRange for z values. The function will try to limit
      * the number of points returned to \a pointsLimit points
      *
-     * \a maxErrorPixels : maximum accepted error factor in pixels
-     *
      * \note this function does not handle elevation properties and you need to
      * change elevation coordinates yourself after returning from the function
      */
@@ -99,8 +99,6 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      * and a range \a extentZRange for z values. The function will try to limit
      * the number of points returned to \a pointsLimit points
      *
-     * \a maxErrorPixels : maximum accepted error factor in pixels
-     *
      * \note this function does not handle elevation properties and you need to
      * change elevation coordinates yourself after returning from the function
      */
@@ -166,6 +164,26 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      */
     virtual QgsPointCloudIndex *index() const SIP_SKIP {return nullptr;}
 
+    /**
+     * Returns a list of sub indexes available if the provider supports multiple indexes, empty list otherwise.
+     *
+     * The sub indexes contain a pointer to the individual indexes which may be nullptr if not yet loaded.
+     *
+     * \note Not available in Python bindings
+     * \since QGIS 3.32
+     */
+    virtual QVector<QgsPointCloudSubIndex> subIndexes() SIP_SKIP { return QVector<QgsPointCloudSubIndex>(); }
+
+    /**
+     * Triggers loading of the point cloud index for the \a n th sub index
+     *
+     * Only applies to providers that support multiple indexes
+     *
+     * \note Not available in Python bindings
+     * \since QGIS 3.32
+     */
+    virtual void loadSubIndex( int n ) SIP_SKIP { Q_UNUSED( n ) return; }
+
     /**
      * Returns whether provider has index which is valid
      */
@@ -211,6 +229,14 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      * providers will return NULLPTR.
      */
     virtual QgsPointCloudRenderer *createRenderer( const QVariantMap &configuration = QVariantMap() ) const SIP_FACTORY;
+
+    /**
+     * Returns whether the dataset contains statistics metadata
+     *
+     * \since QGIS 3.26
+     */
+    virtual bool hasStatisticsMetadata() const;
+
 #ifndef SIP_RUN
 
     /**
@@ -223,7 +249,7 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      *
      * If no matching precalculated statistic is available then an invalid variant will be returned.
      */
-    virtual QVariant metadataStatistic( const QString &attribute, QgsStatisticalSummary::Statistic statistic ) const;
+    virtual QVariant metadataStatistic( const QString &attribute, Qgis::Statistic statistic ) const;
 #else
 
     /**
@@ -236,7 +262,7 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      *
      * \throws ValueError if no matching precalculated statistic is available for the attribute.
      */
-    SIP_PYOBJECT metadataStatistic( const QString &attribute, QgsStatisticalSummary::Statistic statistic ) const;
+    SIP_PYOBJECT metadataStatistic( const QString &attribute, Qgis::Statistic statistic ) const;
     % MethodCode
     {
       const QVariant res = sipCpp->metadataStatistic( *a0, a1 );
@@ -277,7 +303,8 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      *
      * If no matching precalculated statistic is available then an invalid variant will be returned.
      */
-    virtual QVariant metadataClassStatistic( const QString &attribute, const QVariant &value, QgsStatisticalSummary::Statistic statistic ) const;
+    virtual QVariant metadataClassStatistic( const QString &attribute, const QVariant &value, Qgis::Statistic statistic ) const;
+
 #else
 
     /**
@@ -289,7 +316,7 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
      *
      * \throws ValueError if no matching precalculated statistic is available for the attribute.
      */
-    SIP_PYOBJECT metadataClassStatistic( const QString &attribute, const QVariant &value, QgsStatisticalSummary::Statistic statistic ) const;
+    SIP_PYOBJECT metadataClassStatistic( const QString &attribute, const QVariant &value, Qgis::Statistic statistic ) const;
     % MethodCode
     {
       const QVariant res = sipCpp->metadataClassStatistic( *a0, *a1, a2 );
@@ -307,6 +334,17 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
     % End
 #endif
 
+
+    /**
+     * Returns the object containings the statistics metadata extracted from the dataset
+     * \since QGIS 3.26
+     */
+    QgsPointCloudStatistics metadataStatistics();
+
+    bool supportsSubsetString() const override { return true; }
+    QString subsetString() const override;
+    bool setSubsetString( const QString &subset, bool updateFeatureCount = false ) override;
+
     /**
      * Returns the map of LAS classification code to untranslated string value, corresponding to the ASPRS Standard
      * Lidar Point Classes.
@@ -342,10 +380,15 @@ class CORE_EXPORT QgsPointCloudDataProvider: public QgsDataProvider
     /**
      * Emitted when point cloud generation state is changed
      */
-    void indexGenerationStateChanged( PointCloudIndexGenerationState state );
+    void indexGenerationStateChanged( QgsPointCloudDataProvider::PointCloudIndexGenerationState state );
+
+  protected:
+    //! String used to define a subset of the layer
+    QString mSubsetString;
 
   private:
     QVector<IndexedPointCloudNode> traverseTree( const QgsPointCloudIndex *pc, IndexedPointCloudNode n, double maxError, double nodeError, const QgsGeometry &extentGeometry, const QgsDoubleRange &extentZRange );
+
 };
 
 #endif // QGSMESHDATAPROVIDER_H
