@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 /***************************************************************************
 Name                 : DB Manager
@@ -19,7 +17,6 @@ email                : brush.tyler@gmail.com
  *                                                                         *
  ***************************************************************************/
 """
-from builtins import str
 
 # this will disable the dbplugin if the connector raise an ImportError
 from .connector import GPKGDBConnector
@@ -27,7 +24,13 @@ from .connector import GPKGDBConnector
 from qgis.PyQt.QtCore import Qt, QFileInfo, QCoreApplication
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtWidgets import QApplication, QAction, QFileDialog
-from qgis.core import Qgis, QgsApplication, QgsDataSourceUri, QgsSettings
+from qgis.core import (
+    Qgis,
+    QgsApplication,
+    QgsDataSourceUri,
+    QgsSettings,
+    QgsProviderRegistry,
+)
 from qgis.gui import QgsMessageBar
 
 from ..plugin import DBPlugin, Database, Table, VectorTable, RasterTable, TableField, TableIndex, TableTrigger, \
@@ -65,23 +68,22 @@ class GPKGDBPlugin(DBPlugin):
 
     def connect(self, parent=None):
         conn_name = self.connectionName()
-        settings = QgsSettings()
-        settings.beginGroup(u"/%s/%s" % (self.connectionSettingsKey(), conn_name))
 
-        if not settings.contains("path"):  # non-existent entry?
-            raise InvalidDataException(self.tr(u'There is no defined database connection "{0}".').format(conn_name))
+        md = QgsProviderRegistry.instance().providerMetadata(self.providerName())
+        conn = md.findConnection(conn_name)
 
-        database = settings.value("path")
+        if conn is None:  # non-existent entry?
+            raise InvalidDataException(self.tr('There is no defined database connection "{0}".').format(conn_name))
 
         uri = QgsDataSourceUri()
-        uri.setDatabase(database)
+        uri.setDatabase(conn.uri())
         return self.connectToUri(uri)
 
     @classmethod
     def addConnection(self, conn_name, uri):
-        settings = QgsSettings()
-        settings.beginGroup(u"/%s/%s" % (self.connectionSettingsKey(), conn_name))
-        settings.setValue("path", uri.database())
+        md = QgsProviderRegistry.instance().providerMetadata(self.providerName())
+        conn = md.createConnection(uri.database(), {})
+        md.saveConnection(conn, conn_name)
         return True
 
     @classmethod
@@ -93,7 +95,7 @@ class GPKGDBPlugin(DBPlugin):
             if not filename:
                 return
         finally:
-            QApplication.setOverrideCursor(Qt.WaitCursor)
+            QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
 
         conn_name = QFileInfo(filename).fileName()
         uri = QgsDataSourceUri()
@@ -108,7 +110,7 @@ class GPKGDatabase(Database):
         Database.__init__(self, connection, uri)
 
     def connectorsFactory(self, uri):
-        return GPKGDBConnector(uri)
+        return GPKGDBConnector(uri, self.connection())
 
     def dataTablesFactory(self, row, db, schema=None):
         return GPKGTable(row, db, schema)
@@ -145,10 +147,10 @@ class GPKGDatabase(Database):
         try:
             if not isinstance(item, (DBPlugin, Table)) or item.database() is None:
                 parent.infoBar.pushMessage(self.tr("No database selected or you are not connected to it."),
-                                           Qgis.Info, parent.iface.messageTimeout())
+                                           Qgis.MessageLevel.Info, parent.iface.messageTimeout())
                 return
         finally:
-            QApplication.setOverrideCursor(Qt.WaitCursor)
+            QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
 
         self.runVacuum()
 
@@ -173,32 +175,52 @@ class GPKGDatabase(Database):
     def toSqlLayer(self, sql, geomCol, uniqueCol, layerName="QueryLayer", layerType=None, avoidSelectById=False, filter=""):
         from qgis.core import QgsVectorLayer
 
-        vl = QgsVectorLayer(self.uri().database(), layerName, 'ogr')
-        vl.setSubsetString(sql)
+        vl = QgsVectorLayer(self.uri().database() + '|subset=' + sql, layerName, 'ogr')
         return vl
 
+    def supportsComment(self):
+        return False
+
 
 class GPKGTable(Table):
 
     def __init__(self, row, db, schema=None):
+        """Constructs a GPKGTable
+
+        :param row: a three elements array with: [table_name, is_view, is_sys_table]
+        :type row: array [str, bool, bool]
+        :param db: database instance
+        :type db:
+        :param schema: schema name, defaults to None, ignored by GPKG
+        :type schema: str, optional
+        """
+
         Table.__init__(self, db, None)
         self.name, self.isView, self.isSysTable = row
 
     def ogrUri(self):
-        ogrUri = u"%s|layername=%s" % (self.uri().database(), self.name)
+        ogrUri = "%s|layername=%s" % (self.uri().database(), self.name)
         return ogrUri
 
     def mimeUri(self):
-
         # QGIS has no provider to load Geopackage vectors, let's use OGR
-        return u"vector:ogr:%s:%s" % (self.name, self.ogrUri())
+        return "vector:ogr:%s:%s" % (self.name, self.ogrUri())
 
-    def toMapLayer(self):
+    def toMapLayer(self, geometryType=None, crs=None):
         from qgis.core import QgsVectorLayer
 
         provider = "ogr"
         uri = self.ogrUri()
 
+        if geometryType:
+            geom_mapping = {
+                'POINT': 'Point',
+                'LINESTRING': 'LineString',
+                'POLYGON': 'Polygon',
+            }
+            geometryType = geom_mapping[geometryType]
+            uri = "{}|geometrytype={}".format(uri, geometryType)
+
         return QgsVectorLayer(uri, self.name, provider)
 
     def tableFieldsFactory(self, row, table):
@@ -222,7 +244,7 @@ class GPKGVectorTable(GPKGTable, VectorTable):
         GPKGTable.__init__(self, row[:-5], db, schema)
         VectorTable.__init__(self, db, schema)
         # GPKG does case-insensitive checks for table names, but the
-        # GPKG provider didn't do the same in Qgis < 1.9, so self.geomTableName
+        # GPKG provider didn't do the same in QGIS < 1.9, so self.geomTableName
         # stores the table name like stored in the geometry_columns table
         self.geomTableName, self.geomColumn, self.geomType, self.geomDim, self.srid = row[-5:]
         self.extent = self.database().connector.getTableExtent((self.schemaName(), self.name), self.geomColumn, force=False)
@@ -275,22 +297,22 @@ class GPKGRasterTable(GPKGTable, RasterTable):
         self.extent = self.database().connector.getTableExtent((self.schemaName(), self.name), self.geomColumn)
 
     def gpkgGdalUri(self):
-        gdalUri = u'GPKG:%s:%s' % (self.uri().database(), self.prefixName)
+        gdalUri = 'GPKG:%s:%s' % (self.uri().database(), self.prefixName)
         return gdalUri
 
     def mimeUri(self):
         # QGIS has no provider to load rasters, let's use GDAL
-        uri = u"raster:gdal:%s:%s" % (self.name, self.uri().database())
+        uri = "raster:gdal:%s:%s" % (self.name, self.uri().database())
         return uri
 
-    def toMapLayer(self):
+    def toMapLayer(self, geometryType=None, crs=None):
         from qgis.core import QgsRasterLayer, QgsContrastEnhancement
 
         # QGIS has no provider to load rasters, let's use GDAL
         uri = self.gpkgGdalUri()
         rl = QgsRasterLayer(uri, self.name)
         if rl.isValid():
-            rl.setContrastEnhancement(QgsContrastEnhancement.StretchToMinimumMaximum)
+            rl.setContrastEnhancement(QgsContrastEnhancement.ContrastEnhancementAlgorithm.StretchToMinimumMaximum)
         return rl
 
 
