@@ -19,7 +19,6 @@ __author__ = 'Matthias Kuhn'
 __date__ = 'January 2016'
 __copyright__ = '(C) 2016, Matthias Kuhn'
 
-import qgis  # NOQA switch sip api
 
 import os
 import yaml
@@ -49,8 +48,8 @@ from qgis.core import (Qgis,
                        QgsProcessingFeedback)
 from qgis.analysis import (QgsNativeAlgorithms)
 from qgis.testing import (_UnexpectedSuccess,
-                          start_app,
-                          unittest)
+                          QgisTestCase,
+                          start_app)
 from utilities import unitTestDataPath
 
 import processing
@@ -70,7 +69,7 @@ class AlgorithmsTest:
         """
         This is the main test function. All others will be executed based on the definitions in testdata/algorithm_tests.yaml
         """
-        with open(os.path.join(processingTestDataPath(), self.test_definition_file())) as stream:
+        with open(os.path.join(processingTestDataPath(), self.definition_file())) as stream:
             algorithm_tests = yaml.load(stream, Loader=yaml.SafeLoader)
 
         if 'tests' in algorithm_tests and algorithm_tests['tests'] is not None:
@@ -168,9 +167,15 @@ class AlgorithmsTest:
         # ignore user setting for invalid geometry handling
         context = QgsProcessingContext()
         context.setProject(QgsProject.instance())
+        if 'ellipsoid' in defs:
+            # depending on the project settings, we can't always rely
+            # on QgsProject.ellipsoid() returning the same ellipsoid as was
+            # specified in the test definition. So just force ensure that the
+            # context's ellipsoid is the desired one
+            context.setEllipsoid(defs['ellipsoid'])
 
         if 'skipInvalid' in defs and defs['skipInvalid']:
-            context.setInvalidGeometryCheck(QgsFeatureRequest.GeometrySkipInvalid)
+            context.setInvalidGeometryCheck(QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid)
 
         feedback = QgsProcessingFeedback()
 
@@ -436,7 +441,7 @@ class AlgorithmsTest:
                     self.assertRegex(data, rule)
 
 
-class GenericAlgorithmsTest(unittest.TestCase):
+class GenericAlgorithmsTest(QgisTestCase):
     """
     General (non-provider specific) algorithm tests
     """
