@@ -42,13 +42,22 @@ from qgis.PyQt.QtWidgets import (
 )
 from qgis.PyQt.QtNetwork import QNetworkRequest
 
-import qgis
-from qgis.core import Qgis, QgsApplication, QgsNetworkAccessManager, QgsSettings, QgsNetworkRequestParameters
+from qgis.core import Qgis, QgsApplication, QgsMessageLog, QgsNetworkAccessManager, QgsSettings, QgsSettingsTree, QgsNetworkRequestParameters
 from qgis.gui import QgsMessageBar, QgsPasswordLineEdit, QgsHelp
-from qgis.utils import (iface, startPlugin, unloadPlugin, loadPlugin, OverrideCursor,
-                        reloadPlugin, updateAvailablePlugins, plugins_metadata_parser)
+from qgis.utils import (
+    iface,
+    startPlugin,
+    unloadPlugin,
+    loadPlugin,
+    OverrideCursor,
+    reloadPlugin,
+    updateAvailablePlugins,
+    plugins_metadata_parser,
+    isPluginLoaded,
+    HOME_PLUGIN_PATH
+)
 from .installer_data import (repositories, plugins, officialRepo,
-                             settingsGroup, reposGroup, removeDir)
+                             reposGroup, removeDir)
 from .qgsplugininstallerinstallingdialog import QgsPluginInstallerInstallingDialog
 from .qgsplugininstallerpluginerrordialog import QgsPluginInstallerPluginErrorDialog
 from .qgsplugininstallerfetchingdialog import QgsPluginInstallerFetchingDialog
@@ -96,12 +105,12 @@ class QgsPluginInstaller(QObject):
         for key in plugins.obsoletePlugins:
             plugin = plugins.localCache[key]
             msg = QMessageBox()
-            msg.setIcon(QMessageBox.Warning)
+            msg.setIcon(QMessageBox.Icon.Warning)
             msg.setWindowTitle(self.tr("QGIS Python Plugin Installer"))
-            msg.addButton(self.tr("Uninstall (recommended)"), QMessageBox.AcceptRole)
-            msg.addButton(self.tr("I will uninstall it later"), QMessageBox.RejectRole)
+            msg.addButton(self.tr("Uninstall (recommended)"), QMessageBox.ButtonRole.AcceptRole)
+            msg.addButton(self.tr("I will uninstall it later"), QMessageBox.ButtonRole.RejectRole)
             msg.setText("%s <b>%s</b><br/><br/>%s" % (self.tr("Obsolete plugin:"), plugin["name"], self.tr("QGIS has detected an obsolete plugin that masks its more recent version shipped with this copy of QGIS. This is likely due to files associated with a previous installation of QGIS. Do you want to remove the old plugin right now and unmask the more recent version?")))
-            msg.exec_()
+            msg.exec()
             if not msg.result():
                 settings = QgsSettings()
                 plugin_is_active = settings.value("/PythonPlugins/" + key, False, type=bool)
@@ -120,30 +129,29 @@ class QgsPluginInstaller(QObject):
         """ Fetch plugins from all enabled repositories."""
         """  reloadMode = true:  Fully refresh data from QgsSettings to mRepositories  """
         """  reloadMode = false: Fetch unready repositories only """
-        with OverrideCursor(Qt.WaitCursor):
-            if reloadMode:
-                repositories.load()
-                plugins.clearRepoCache()
-                plugins.getAllInstalled()
+        if reloadMode:
+            repositories.load()
+            plugins.clearRepoCache()
+            plugins.getAllInstalled()
 
-            for key in repositories.allEnabled():
-                if reloadMode or repositories.all()[key]["state"] == 3:  # if state = 3 (error or not fetched yet), try to fetch once again
-                    repositories.requestFetching(key, force_reload=reloadMode)
+        for key in repositories.allEnabled():
+            if reloadMode or repositories.all()[key]["state"] == 3:  # if state = 3 (error or not fetched yet), try to fetch once again
+                repositories.requestFetching(key, force_reload=reloadMode)
 
-            if repositories.fetchingInProgress():
-                fetchDlg = QgsPluginInstallerFetchingDialog(iface.mainWindow())
-                fetchDlg.exec_()
-                del fetchDlg
-                for key in repositories.all():
-                    repositories.killConnection(key)
+        if repositories.fetchingInProgress():
+            fetchDlg = QgsPluginInstallerFetchingDialog(iface.mainWindow())
+            fetchDlg.exec()
+            del fetchDlg
+            for key in repositories.all():
+                repositories.killConnection(key)
 
         # display error messages for every unavailable repository, unless Shift pressed nor all repositories are unavailable
-        keepQuiet = QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier)
+        keepQuiet = QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.KeyboardModifier.ShiftModifier)
         if repositories.allUnavailable() and repositories.allUnavailable() != repositories.allEnabled():
             for key in repositories.allUnavailable():
                 if not keepQuiet:
                     QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), self.tr("Error reading repository:") + " " + key + "\n\n" + repositories.all()[key]["error"])
-                if QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
+                if QgsApplication.keyboardModifiers() == Qt.KeyboardModifiers(Qt.KeyboardModifier.ShiftModifier):
                     keepQuiet = True
         # finally, rebuild plugins from the caches
         plugins.rebuild()
@@ -156,30 +164,30 @@ class QgsPluginInstaller(QObject):
         plugins.rebuild()
         # look for news in the repositories
         plugins.markNews()
-        status = None
         # then check for updates (and eventually overwrite status)
-        updatable_count = 0
-        updatable_plugin_name = None
+        updatable_plugin_names = []
         for _, properties in plugins.all().items():
             if properties["status"] == "upgradeable":
-                updatable_count += 1
-                updatable_plugin_name = properties["name"]
+                updatable_plugin_names.append(properties["name"])
 
-        if updatable_count:
-            if updatable_count > 1:
-                status = self.tr("Multiple plugin updates are available")
-            else:
-                status = self.tr("An update to the {} plugin is available").format(updatable_plugin_name)
-            tabIndex = 3  # PLUGMAN_TAB_UPGRADEABLE
+        if not updatable_plugin_names:
+            return
 
-        # finally set the notify label
-        if status:
-            bar = iface.messageBar()
-            self.message_bar_widget = bar.createMessage('', status)
-            update_button = QPushButton("Install Updates…")
-            update_button.pressed.connect(partial(self.showPluginManagerWhenReady, tabIndex))
-            self.message_bar_widget.layout().addWidget(update_button)
-            bar.pushWidget(self.message_bar_widget, Qgis.Info)
+        if len(updatable_plugin_names) >= 2:
+            status = self.tr("Multiple plugin updates are available")
+        else:
+            status = self.tr("An update to the {} plugin is available").format(updatable_plugin_names[0])
+
+        QgsMessageLog.logMessage(
+            "Plugin update(s) available : {}".format(','.join(updatable_plugin_names)), self.tr("Plugins"))
+
+        bar = iface.messageBar()
+        self.message_bar_widget = bar.createMessage('', status)
+        update_button = QPushButton(self.tr("Install Updates…"))
+        tab_index = 3  # PLUGMAN_TAB_UPGRADEABLE
+        update_button.pressed.connect(partial(self.showPluginManagerWhenReady, tab_index))
+        self.message_bar_widget.layout().addWidget(update_button)
+        bar.pushWidget(self.message_bar_widget, Qgis.MessageLevel.Info)
 
     # ----------------------------------------- #
     def exportRepositoriesToManager(self):
@@ -293,7 +301,8 @@ class QgsPluginInstaller(QObject):
     # ----------------------------------------- #
     def exportSettingsGroup(self):
         """ Return QgsSettings settingsGroup value """
-        return settingsGroup
+        # todo QGIS 4 remove
+        return "plugin-manager"
 
     # ----------------------------------------- #
     def upgradeAllUpgradeable(self):
@@ -312,16 +321,24 @@ class QgsPluginInstaller(QObject):
         if not plugin:
             return
         if plugin[status_key] == "newer" and not plugin["error"]:  # ask for confirmation if user downgrades an usable plugin
-            if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), self.tr("Are you sure you want to downgrade the plugin to the latest available version? The installed one is newer!"), QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
+            if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), self.tr("Are you sure you want to downgrade the plugin to the latest available version? The installed one is newer!"), QMessageBox.StandardButton.Yes, QMessageBox.StandardButton.No) == QMessageBox.StandardButton.No:
                 return
 
-        dlg = QgsPluginInstallerInstallingDialog(iface.mainWindow(), plugin, stable=stable)
-        dlg.exec_()
+        # if plugin is active, unload it before update, see https://github.com/qgis/QGIS/issues/54968
+        pluginWasLoaded = isPluginLoaded(plugin["id"])
+        if pluginWasLoaded:
+            unloadPlugin(plugin["id"])
 
-        plugin_path = qgis.utils.home_plugin_path + "/" + key
+        dlg = QgsPluginInstallerInstallingDialog(iface.mainWindow(), plugin, stable=stable)
+        dlg.exec()
+
+        plugin_path = HOME_PLUGIN_PATH + "/" + key
         if dlg.result():
             error = True
             infoString = (self.tr("Plugin installation failed"), dlg.result())
+            # download failed or aborted. If plugin was active before the update, let's try to load it back
+            if pluginWasLoaded and loadPlugin(plugin["id"]):
+                startPlugin(plugin["id"])
         elif not QDir(plugin_path).exists():
             error = True
             infoString = (
@@ -332,12 +349,12 @@ class QgsPluginInstaller(QObject):
                     "the list of installed plugins. You should find the plugin there, but it's not possible to "
                     "determine which of them it is and it's also not possible to inform you about available updates. "
                     "Please contact the plugin author and submit this issue.").format(plugin_path))
-            with OverrideCursor(Qt.WaitCursor):
+            with OverrideCursor(Qt.CursorShape.WaitCursor):
                 plugins.getAllInstalled()
                 plugins.rebuild()
                 self.exportPluginsToManager()
         else:
-            QApplication.setOverrideCursor(Qt.WaitCursor)
+            QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
             # update the list of plugins in plugin handling routines
             updateAvailablePlugins()
             self.processDependencies(plugin["id"])
@@ -353,14 +370,13 @@ class QgsPluginInstaller(QObject):
                         settings = QgsSettings()
                         settings.setValue("/PythonPlugins/" + plugin["id"], True)
                 else:
-                    settings = QgsSettings()
-                    if settings.value("/PythonPlugins/" + key, False, type=bool):  # plugin will be reloaded on the fly only if currently loaded
-                        reloadPlugin(key)  # unloadPlugin + loadPlugin + startPlugin
-                        infoString = (self.tr("Plugin reinstalled successfully"), "")
+                    infoString = (self.tr("Plugin reinstalled successfully"), "")
+                    if pluginWasLoaded:
+                        loadPlugin(plugin["id"])
+                        startPlugin(plugin["id"])
                     else:
                         unloadPlugin(key)  # Just for a case. Will exit quietly if really not loaded
                         loadPlugin(key)
-                        infoString = (self.tr("Plugin reinstalled successfully"), self.tr("Python plugin reinstalled.\nYou need to restart QGIS in order to reload it."))
                 if quiet:
                     infoString = (None, None)
                 QApplication.restoreOverrideCursor()
@@ -376,10 +392,10 @@ class QgsPluginInstaller(QObject):
                     message = self.tr("The plugin is broken. Python said:")
                     message += "<br><b>" + plugin["error_details"] + "</b>"
                 dlg = QgsPluginInstallerPluginErrorDialog(iface.mainWindow(), message)
-                dlg.exec_()
+                dlg.exec()
                 if dlg.result():
                     # revert installation
-                    pluginDir = qgis.utils.home_plugin_path + "/" + plugin["id"]
+                    pluginDir = HOME_PLUGIN_PATH + "/" + plugin["id"]
                     result = removeDir(pluginDir)
                     if QDir(pluginDir).exists():
                         error = True
@@ -401,7 +417,7 @@ class QgsPluginInstaller(QObject):
             self.exportPluginsToManager()
 
         if infoString[0]:
-            level = error and Qgis.Critical or Qgis.Info
+            level = error and Qgis.MessageLevel.Critical or Qgis.MessageLevel.Info
             msg = "<b>%s</b>" % infoString[0]
             if infoString[1]:
                 msg += "<b>:</b> %s" % infoString[1]
@@ -420,20 +436,20 @@ class QgsPluginInstaller(QObject):
             warning = self.tr("Are you sure you want to uninstall the following plugin?") + "\n(" + plugin["name"] + ")"
             if plugin["status"] == "orphan" and plugin["status_exp"] == "orphan" and not plugin["error"]:
                 warning += "\n\n" + self.tr("Warning: this plugin isn't available in any accessible repository!")
-            if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), warning, QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
+            if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), warning, QMessageBox.StandardButton.Yes, QMessageBox.StandardButton.No) == QMessageBox.StandardButton.No:
                 return
         # unload the plugin
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         try:
             unloadPlugin(key)
         except:
             pass
-        pluginDir = qgis.utils.home_plugin_path + "/" + plugin["id"]
+        pluginDir = HOME_PLUGIN_PATH + "/" + plugin["id"]
         result = removeDir(pluginDir)
         if result:
             QApplication.restoreOverrideCursor()
             msg = "<b>%s:</b>%s" % (self.tr("Plugin uninstall failed"), result)
-            iface.pluginManagerInterface().pushMessage(msg, Qgis.Critical)
+            iface.pluginManagerInterface().pushMessage(msg, Qgis.MessageLevel.Critical)
         else:
             # safe remove
             try:
@@ -458,7 +474,7 @@ class QgsPluginInstaller(QObject):
             plugins.rebuild()
             self.exportPluginsToManager()
             QApplication.restoreOverrideCursor()
-            iface.pluginManagerInterface().pushMessage(self.tr("Plugin uninstalled successfully"), Qgis.Info)
+            iface.pluginManagerInterface().pushMessage(self.tr("Plugin uninstalled successfully"), Qgis.MessageLevel.Success)
 
             settings = QgsSettings()
             settings.remove("/PythonPlugins/" + key)
@@ -468,12 +484,12 @@ class QgsPluginInstaller(QObject):
         """ add new repository connection """
         dlg = QgsPluginInstallerRepositoryDialog(iface.mainWindow())
         dlg.editParams.setText(repositories.urlParams())
-        dlg.checkBoxEnabled.setCheckState(Qt.Checked)
-        if not dlg.exec_():
+        dlg.checkBoxEnabled.setCheckState(Qt.CheckState.Checked)
+        if not dlg.exec():
             return
         for i in list(repositories.all().values()):
             if dlg.editURL.text().strip() == i["url"]:
-                iface.pluginManagerInterface().pushMessage(self.tr("Unable to add another repository with the same URL!"), Qgis.Warning)
+                iface.pluginManagerInterface().pushMessage(self.tr("Unable to add another repository with the same URL!"), Qgis.MessageLevel.Warning)
                 return
         settings = QgsSettings()
         settings.beginGroup(reposGroup)
@@ -494,7 +510,7 @@ class QgsPluginInstaller(QObject):
         """ edit repository connection """
         if not reposName:
             return
-        checkState = {False: Qt.Unchecked, True: Qt.Checked}
+        checkState = {False: Qt.CheckState.Unchecked, True: Qt.CheckState.Checked}
         dlg = QgsPluginInstallerRepositoryDialog(iface.mainWindow())
         dlg.editName.setText(reposName)
         dlg.editURL.setText(repositories.all()[reposName]["url"])
@@ -507,12 +523,12 @@ class QgsPluginInstaller(QObject):
         else:
             dlg.checkBoxEnabled.setEnabled(False)
             dlg.labelInfo.setText(self.tr("This repository is blocked due to incompatibility with your QGIS version"))
-            dlg.labelInfo.setFrameShape(QFrame.Box)
-        if not dlg.exec_():
+            dlg.labelInfo.setFrameShape(QFrame.Shape.Box)
+        if not dlg.exec():
             return  # nothing to do if canceled
         for i in list(repositories.all().values()):
             if dlg.editURL.text().strip() == i["url"] and dlg.editURL.text().strip() != repositories.all()[reposName]["url"]:
-                iface.pluginManagerInterface().pushMessage(self.tr("Unable to add another repository with the same URL!"), Qgis.Warning)
+                iface.pluginManagerInterface().pushMessage(self.tr("Unable to add another repository with the same URL!"), Qgis.MessageLevel.Warning)
                 return
         # delete old repo from QgsSettings and create new one
         settings = QgsSettings()
@@ -541,10 +557,10 @@ class QgsPluginInstaller(QObject):
         settings = QgsSettings()
         settings.beginGroup(reposGroup)
         if settings.value(reposName + "/url", "", type=str) == officialRepo[1]:
-            iface.pluginManagerInterface().pushMessage(self.tr("You can't remove the official QGIS Plugin Repository. You can disable it if needed."), Qgis.Warning)
+            iface.pluginManagerInterface().pushMessage(self.tr("You can't remove the official QGIS Plugin Repository. You can disable it if needed."), Qgis.MessageLevel.Warning)
             return
         warning = self.tr("Are you sure you want to remove the following repository?") + "\n" + reposName
-        if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), warning, QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
+        if QMessageBox.warning(iface.mainWindow(), self.tr("QGIS Python Plugin Installer"), warning, QMessageBox.StandardButton.Yes, QMessageBox.StandardButton.No) == QMessageBox.StandardButton.No:
             return
         # delete from the settings, refresh data and repopulate all the widgets
         settings.remove(reposName)
@@ -564,22 +580,23 @@ class QgsPluginInstaller(QObject):
 
         if not plugin_id or not vote:
             return False
-        url = "http://plugins.qgis.org/plugins/RPC2/"
+        url = "https://plugins.qgis.org/plugins/RPC2/"
         params = {"id": "djangorpc", "method": "plugin.vote", "params": [str(plugin_id), str(vote)]}
         req = QNetworkRequest(QUrl(url))
-        req.setAttribute(QNetworkRequest.Attribute(QgsNetworkRequestParameters.AttributeInitiatorClass), "QgsPluginInstaller")
-        req.setAttribute(QNetworkRequest.Attribute(QgsNetworkRequestParameters.AttributeInitiatorRequestId), "sendVote")
+        req.setAttribute(QNetworkRequest.Attribute(QgsNetworkRequestParameters.RequestAttributes.AttributeInitiatorClass), "QgsPluginInstaller")
+        req.setAttribute(QNetworkRequest.Attribute(QgsNetworkRequestParameters.RequestAttributes.AttributeInitiatorRequestId), "sendVote")
         req.setRawHeader(b"Content-Type", b"application/json")
-        QgsNetworkAccessManager.instance().post(req, bytes(json.dumps(params), "utf-8"))
-        return True
+        reply = QgsNetworkAccessManager.instance().blockingPost(req, bytes(json.dumps(params), "utf-8"))
+        if reply.attribute(QNetworkRequest.Attribute.HttpStatusCodeAttribute) == 200:
+            return True
+        else:
+            return False
 
     def installFromZipFile(self, filePath):
         if not os.path.isfile(filePath):
             return
 
-        settings = QgsSettings()
-        settings.setValue(settingsGroup + '/lastZipDirectory',
-                          QFileInfo(filePath).absoluteDir().absolutePath())
+        QgsSettingsTree.node("plugin-manager").childSetting("last-zip-directory").setValue(QFileInfo(filePath).absoluteDir().absolutePath())
 
         pluginName = None
         with zipfile.ZipFile(filePath, 'r') as zf:
@@ -593,22 +610,26 @@ class QgsPluginInstaller(QObject):
 
         if not pluginName:
             msg_box = QMessageBox()
-            msg_box.setIcon(QMessageBox.Warning)
+            msg_box.setIcon(QMessageBox.Icon.Warning)
             msg_box.setWindowTitle(self.tr("QGIS Python Install from ZIP Plugin Installer"))
             msg_box.setText(self.tr("The Zip file is not a valid QGIS python plugin. No root folder was found inside."))
-            msg_box.setStandardButtons(QMessageBox.Ok)
-            more_info_btn = msg_box.addButton(self.tr("More Information"), QMessageBox.HelpRole)
+            msg_box.setStandardButtons(QMessageBox.StandardButton.Ok)
+            more_info_btn = msg_box.addButton(self.tr("More Information"), QMessageBox.ButtonRole.HelpRole)
             msg_box.exec()
             if msg_box.clickedButton() == more_info_btn:
                 QgsHelp.openHelp("plugins/plugins.html#the-install-from-zip-tab")
             return
 
-        pluginsDirectory = qgis.utils.home_plugin_path
+        pluginsDirectory = HOME_PLUGIN_PATH
         if not QDir(pluginsDirectory).exists():
             QDir().mkpath(pluginsDirectory)
 
         pluginDirectory = QDir.cleanPath(os.path.join(pluginsDirectory, pluginName))
 
+        # if plugin is active, unload it before update, see https://github.com/qgis/QGIS/issues/54968
+        if isPluginLoaded(pluginName):
+            unloadPlugin(pluginName)
+
         # If the target directory already exists as a link,
         # remove the link without resolving
         QFile(pluginDirectory).remove()
@@ -639,7 +660,7 @@ class QgsPluginInstaller(QObject):
                     # Display a password dialog with QgsPasswordLineEdit
                     dlg = QDialog()
                     dlg.setWindowTitle(self.tr('Enter password'))
-                    buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel, Qt.Horizontal)
+                    buttonBox = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok | QDialogButtonBox.StandardButton.Cancel, Qt.Orientation.Horizontal)
                     buttonBox.rejected.connect(dlg.reject)
                     buttonBox.accepted.connect(dlg.accept)
                     lePass = QgsPasswordLineEdit()
@@ -648,20 +669,21 @@ class QgsPluginInstaller(QObject):
                     layout.addWidget(lePass)
                     layout.addWidget(buttonBox)
                     dlg.setLayout(layout)
-                    keepTrying = dlg.exec_()
+                    keepTrying = dlg.exec()
                     password = lePass.text()
                 else:
                     infoString = self.tr("Failed to unzip the plugin package\n{}.\nProbably it is broken".format(filePath))
                     keepTrying = False
 
         if success:
-            with OverrideCursor(Qt.WaitCursor):
+            with OverrideCursor(Qt.CursorShape.WaitCursor):
                 updateAvailablePlugins()
                 self.processDependencies(pluginName)
                 loadPlugin(pluginName)
                 plugins.getAllInstalled()
                 plugins.rebuild()
 
+                settings = QgsSettings()
                 if settings.contains('/PythonPlugins/' + pluginName):  # Plugin was available?
                     if settings.value('/PythonPlugins/' + pluginName, False, bool):  # Plugin was also active?
                         reloadPlugin(pluginName)  # unloadPlugin + loadPlugin + startPlugin
@@ -677,7 +699,7 @@ class QgsPluginInstaller(QObject):
         else:
             msg = "<b>%s:</b> %s" % (self.tr("Plugin installation failed"), infoString)
 
-        level = Qgis.Info if success else Qgis.Critical
+        level = Qgis.MessageLevel.Success if success else Qgis.MessageLevel.Critical
         iface.pluginManagerInterface().pushMessage(msg, level)
 
     def processDependencies(self, plugin_id):
@@ -690,21 +712,21 @@ class QgsPluginInstaller(QObject):
         to_install, to_upgrade, not_found = find_dependencies(plugin_id)
         if to_install or to_upgrade or not_found:
             dlg = QgsPluginDependenciesDialog(plugin_id, to_install, to_upgrade, not_found)
-            if dlg.exec_() == QgsPluginDependenciesDialog.Accepted:
+            if dlg.exec() == QgsPluginDependenciesDialog.Accepted:
                 actions = dlg.actions()
                 for dependency_plugin_id, action_data in actions.items():
                     try:
                         self.installPlugin(dependency_plugin_id, stable=action_data['use_stable_version'])
                         if action_data['action'] == 'install':
                             iface.pluginManagerInterface().pushMessage(self.tr("Plugin dependency <b>%s</b> successfully installed") %
-                                                                       dependency_plugin_id, Qgis.Info)
+                                                                       dependency_plugin_id, Qgis.MessageLevel.Success)
                         else:
                             iface.pluginManagerInterface().pushMessage(self.tr("Plugin dependency <b>%s</b> successfully upgraded") %
-                                                                       dependency_plugin_id, Qgis.Info)
+                                                                       dependency_plugin_id, Qgis.MessageLevel.Success)
                     except Exception as ex:
                         if action_data['action'] == 'install':
                             iface.pluginManagerInterface().pushMessage(self.tr("Error installing plugin dependency <b>%s</b>: %s") %
-                                                                       (dependency_plugin_id, ex), Qgis.Warning)
+                                                                       (dependency_plugin_id, ex), Qgis.MessageLevel.Warning)
                         else:
                             iface.pluginManagerInterface().pushMessage(self.tr("Error upgrading plugin dependency <b>%s</b>: %s") %
-                                                                       (dependency_plugin_id, ex), Qgis.Warning)
+                                                                       (dependency_plugin_id, ex), Qgis.MessageLevel.Warning)
